/* ----------------------------------------------------------------------------------------------------------------------
* © Copyright 2019 Visa. All Rights Reserved.
*
* NOTICE: The software and accompanying information and documentation (together, the “Software”) remain the property of
* and are proprietary to Visa and its suppliers and affiliates. The Software remains protected by intellectual property
* rights and may be covered by U.S. and foreign patents or patent applications. The Software is licensed and not sold.
*
* By accessing the Software you are agreeing to Visa's terms of use (developer.visa.com/terms) and privacy policy
* (developer.visa.com/privacy). In addition, all permissible uses of the Software must be in support of Visa products,
* programs and services provided through the Visa Developer Program (VDP) platform only (developer.visa.com).
* THE SOFTWARE AND ANY ASSOCIATED INFORMATION OR DOCUMENTATION IS PROVIDED ON AN “AS IS,” “AS AVAILABLE,” “WITH ALL
* FAULTS” BASIS WITHOUT WARRANTY OR CONDITION OF ANY KIND. YOUR USE IS AT YOUR OWN RISK.
---------------------------------------------------------------------------------------------------------------------- */
/*
 * Foreign Exchange Rates API
 * The Foreign Exchange Rates API provides an easy access to the Visa daily currency conversion rate for a given currency pair. This is an indicative rate which is dependent on the currency pair as well as the amount, and may be different from the actual rate for settlement of transaction. *
 * OpenAPI spec version: v1
 */

package com.visa.developer.sample.foreign_exchange_rates_api.model;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModelProperty;


/**
 * Address
 */

public class Address {

    @JsonSerialize(include = JsonSerialize.Inclusion.NON_NULL)
    @JsonProperty("city")
    String city = null;// = "Belmont";

    @JsonSerialize(include = JsonSerialize.Inclusion.NON_NULL)
    @JsonProperty("country")
    String country = null;// = "US";

    @JsonSerialize(include = JsonSerialize.Inclusion.NON_NULL)
    @JsonProperty("county")
    String county = null;// = "San Mateo";

    @JsonSerialize(include = JsonSerialize.Inclusion.NON_NULL)
    @JsonProperty("state")
    String state = null;// = "CA";

    @JsonSerialize(include = JsonSerialize.Inclusion.NON_NULL)
    @JsonProperty("zipCode")
    String zipCode = null;// = "94002";

    /**
     * Get City
     * @return City
     *
     * Possible values : string length:1-13
     * City of the funds transfer originator/operator.
     **/
    @ApiModelProperty(value = "City")
    public String getCity() {
        return city;
    }
    public void setCity(String city) {
        this.city = city;
    }
    public Address city(String city) {
        this.city = city;
        return this;
    }

    /**
     * Get Country
     * @return Country
     *
     * Possible values : string length:2-3
     * This field must contain the 3-character alpha country code for the country of
     * the originator or funds transfer operator.
     * Reference url:
     * https://developer.visa.com/request_response_codes#iso_country_and_currency_codes
     **/
    @ApiModelProperty(value = "Country")
    public String getCountry() {
        return country;
    }
    public void setCountry(String country) {
        this.country = country;
    }
    public Address country(String country) {
        this.country = country;
        return this;
    }


    /**
     * Get County
     * @return County
     *
     * County of the funds transfer operator/originator
     **/
    @ApiModelProperty(value = "County")
    public String getCounty() {
        return county;
    }
    public void setCounty(String county) {
        this.county = county;
    }
    public Address county(String county) {
        this.county = county;
        return this;
    }

    /**
     * Get State
     * @return State
     *
     * Possible values : string length:2
     * Use a 2-character abbreviated states code or territory code as the state value.
     * Make sure to give a valid state code for given country.
     **/
    @ApiModelProperty(value = "State")
    public String getState() {
        return state;
    }
    public void setState(String state) {
        this.state = state;
    }
    public Address state(String state) {
        this.state = state;
        return this;
    }

    /**
     * Zip Code
     * @return Zip Code
     *
     * Possible values : string length:5-9
     * Zip/Postal code of the funds transfer operator/originator.
     **/
    @ApiModelProperty(value = "Zip Code")
    public String getZipCode() {
        return zipCode;
    }
    public void setZipCode(String zipCode) {
        this.zipCode = zipCode;
    }
    public Address zipCode(String zipCode) {
        this.zipCode = zipCode;
        return this;
    }

    @Override
    public String toString() {
        return new String("class Address {\n\t\t\tcity: " + city + "\n\t\t\tcountry: "
                + country + "\n\t\t\tcounty: " + county + "\n\t\t\tstate: " + state
                + "\n\t\t\tzipCode: " + zipCode + "\n\t\t}");
    }
}