/* ----------------------------------------------------------------------------------------------------------------------
* © Copyright 2019 Visa. All Rights Reserved.
*
* NOTICE: The software and accompanying information and documentation (together, the “Software”) remain the property of
* and are proprietary to Visa and its suppliers and affiliates. The Software remains protected by intellectual property
* rights and may be covered by U.S. and foreign patents or patent applications. The Software is licensed and not sold.
*
* By accessing the Software you are agreeing to Visa's terms of use (developer.visa.com/terms) and privacy policy
* (developer.visa.com/privacy). In addition, all permissible uses of the Software must be in support of Visa products,
* programs and services provided through the Visa Developer Program (VDP) platform only (developer.visa.com).
* THE SOFTWARE AND ANY ASSOCIATED INFORMATION OR DOCUMENTATION IS PROVIDED ON AN “AS IS,” “AS AVAILABLE,” “WITH ALL
* FAULTS” BASIS WITHOUT WARRANTY OR CONDITION OF ANY KIND. YOUR USE IS AT YOUR OWN RISK.
---------------------------------------------------------------------------------------------------------------------- */
/*
 * Foreign Exchange Rates API
 * The Foreign Exchange Rates API provides an easy access to the Visa daily currency conversion rate for a given currency pair. This is an indicative rate which is dependent on the currency pair as well as the amount, and may be different from the actual rate for settlement of transaction. *
 * OpenAPI spec version: v1
 */

package com.visa.developer.sample.foreign_exchange_rates_api.model;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModelProperty;


/**
 * CardAcceptor
 */

public class CardAcceptor {

    @JsonSerialize(include = JsonSerialize.Inclusion.NON_NULL)
    @JsonProperty("address")
    Address address = null; // = {Address object};

    @JsonSerialize(include = JsonSerialize.Inclusion.NON_NULL)
    @JsonProperty("idCode")
    String idCode = null; // = "ABCD1234ABCD123";

    @JsonSerialize(include = JsonSerialize.Inclusion.NON_NULL)
    @JsonProperty("name")
    String name = null; // = "ABCD";

    @JsonSerialize(include = JsonSerialize.Inclusion.NON_NULL)
    @JsonProperty("terminalId")
    String terminalId = null; // = "ABCD1234";

    /**
     * Get Address
     * @return Address
     *
     * Possible values : Address object
     * Address of the funds transfer originator/operator.
     **/
    @ApiModelProperty(value = "Address")
    public Address getAddress() {
        return address;
    }
    public void setAddress(Address address) {
        this.address = address;
    }
    public CardAcceptor address(Address address) {
        this.address = address;
        return this;
    }

    /**
     * Get ID Code
     * @return ID Code
     *
     * Possible values : string length:1-15
     * An identifier for the card acceptor (Funds Transfer Originator). 
     * This value should be unique for each originator for whom you are sending transactions.
     **/
    @ApiModelProperty(value = "ID Code")
    public String getIdCode() {
        return idCode;
    }
    public void setIdCode(String idCode) {
        this.idCode = idCode;
    }
    public CardAcceptor idCode(String idCode) {
        this.idCode = idCode;
        return this;
    }

    /**
     * Get Name
     * @return Name
     *
     * Possible values : string length:1-25
     * Name of the Card Acceptor
     **/
    @ApiModelProperty(value = "Name")
    public String getName() {
        return name;
    }
    public void setName(String name) {
        this.name = name;
    }
    public CardAcceptor name(String name) {
        this.name = name;
        return this;
    }

    /**
     * Get Terminal ID
     * @return Terminal ID
     *
     * Possible values : string length:1-8
     * The identifier for the terminal at a card acceptor location. 
     * If sending transactions from a card not present context, use the same value for
     * all transactions.
     **/
    @ApiModelProperty(value = "Terminal ID")
    public String getTerminalId() {
        return terminalId;
    }
    public void setTerminalId(String terminalId) {
        this.terminalId = terminalId;
    }
    public CardAcceptor terminalId(String terminalId) {
        this.terminalId = terminalId;
        return this;
    }

    @Override
    public String toString() {
        return "class CardAcceptor {\n\t\taddress: " + address + "\n\t\tidCode: " + idCode
                + "\n\t\tname: " + name + "\n\t\tterminalId: " + terminalId + "\n\t}";
    }
}