/* ----------------------------------------------------------------------------------------------------------------------
* © Copyright 2019 Visa. All Rights Reserved.
*
* NOTICE: The software and accompanying information and documentation (together, the “Software”) remain the property of
* and are proprietary to Visa and its suppliers and affiliates. The Software remains protected by intellectual property
* rights and may be covered by U.S. and foreign patents or patent applications. The Software is licensed and not sold.
*
* By accessing the Software you are agreeing to Visa's terms of use (developer.visa.com/terms) and privacy policy
* (developer.visa.com/privacy). In addition, all permissible uses of the Software must be in support of Visa products,
* programs and services provided through the Visa Developer Program (VDP) platform only (developer.visa.com).
* THE SOFTWARE AND ANY ASSOCIATED INFORMATION OR DOCUMENTATION IS PROVIDED ON AN “AS IS,” “AS AVAILABLE,” “WITH ALL
* FAULTS” BASIS WITHOUT WARRANTY OR CONDITION OF ANY KIND. YOUR USE IS AT YOUR OWN RISK.
---------------------------------------------------------------------------------------------------------------------- */
/*
 * Foreign Exchange Rates API
 * The Foreign Exchange Rates API provides an easy access to the Visa daily currency conversion rate for a given currency pair. This is an indicative rate which is dependent on the currency pair as well as the amount, and may be different from the actual rate for settlement of transaction. *
 * OpenAPI spec version: v1
 */

package com.visa.developer.sample.foreign_exchange_rates_api.model;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModelProperty;


/**
 * FXInquirypostPayload
 */

public class FXInquirypostPayload {

    @JsonSerialize(include = JsonSerialize.Inclusion.NON_NULL)
    @JsonProperty("cardAcceptor")
    CardAcceptor cardAcceptor = null;

    @JsonSerialize(include = JsonSerialize.Inclusion.NON_NULL)
    @JsonProperty("destinationCurrencyCode")
    String destinationCurrencyCode = null;

    @JsonSerialize(include = JsonSerialize.Inclusion.NON_NULL)
    @JsonProperty("markUpRate")
    String markUpRate = null;

    @JsonSerialize(include = JsonSerialize.Inclusion.NON_NULL)
    @JsonProperty("retrievalReferenceNumber")
    String retrievalReferenceNumber = null;

    @JsonSerialize(include = JsonSerialize.Inclusion.NON_NULL)
    @JsonProperty("sourceAmount")
    String sourceAmount = null;

    @JsonSerialize(include = JsonSerialize.Inclusion.NON_NULL)
    @JsonProperty("sourceCurrencyCode")
    String sourceCurrencyCode = null;

    @JsonSerialize(include = JsonSerialize.Inclusion.NON_NULL)
    @JsonProperty("systemsTraceAuditNumber")
    String systemsTraceAuditNumber = null;

    /**
     *Get Card Acceptor
     * @return Card Acceptor
     *
     * Possible values : CardAcceptor object
     * The clients of Funds Transfer APIs can choose to provide card acceptor information
     * for reporting purposes.
     **/
    @ApiModelProperty(value = "Card Acceptor")
    public CardAcceptor getCardAcceptor() {
        return cardAcceptor;
    }
    public void setCardAcceptor(CardAcceptor cardAcceptor) {
        this.cardAcceptor = cardAcceptor;
    }
    public FXInquirypostPayload cardAcceptor(CardAcceptor cardAcceptor) {
        this.cardAcceptor = cardAcceptor;
        return this;
    }

    /**
     * Get Destination Currency Code
     * @return Destination Currency Code
     *
     * Possible values : String Alphanumeric length: 3
     * Reference url:
     * https://developer.visa.com/request_response_codes#iso_country_and_currency_codes
     **/
    @ApiModelProperty(required = true, value = "")
    public String getDestinationCurrencyCode() {
        return destinationCurrencyCode;
    }
    public void setDestinationCurrencyCode(String destinationCurrencyCode) {
        this.destinationCurrencyCode = destinationCurrencyCode;
    }
    public FXInquirypostPayload destinationCurrencyCode(String destinationCurrencyCode) {
        this.destinationCurrencyCode = destinationCurrencyCode;
        return this;
    }

    /**
     * Get Mark Up Rate
     * @return Mark Up Rate
     * The FX mark up rate to be applied. Required if the client wants certain FX rate applied.
     * Example: A value of 0.07 will have 0.07% FX markup rate applied.
     **/
    @ApiModelProperty(value = "Percent markup rate")
    public String getMarkUpRate() {
        return markUpRate;
    }
    public void setMarkUpRate(String markUpRate) {
        this.markUpRate = markUpRate;
    }
    public FXInquirypostPayload markUpRate(String markUpRate) {
        this.markUpRate = markUpRate;
        return this;
    }

    /**
     * Get Retrieval Reference Number
     * @return Retrieval Reference Number
     *
     * Possible values : String (numeric characters only),length: 12
     * It is recommended that the clients of Funds Transfer APIs provide retrievalReferenceNumber
     *to tie the calls with a single funds transfer transaction.
     **/
    @ApiModelProperty(value = "Fund Retrieval Reference Number")
    public String getRetrievalReferenceNumber() {
        return retrievalReferenceNumber;
    }
    public void setRetrievalReferenceNumber(String retrievalReferenceNumber) {
        this.retrievalReferenceNumber = retrievalReferenceNumber;
    }
    public FXInquirypostPayload retrievalReferenceNumber(String retrievalReferenceNumber) {
        this.retrievalReferenceNumber = retrievalReferenceNumber;
        return this;
    }

    /**
     * Get Source Amount
     * @return Source Amount
     *
     * Possible values : String decimal length: totalDigits 12, fractionDigits 3
     * The amount to be converted. This should be in the source currency denomination.
     **/
    @ApiModelProperty(required = true, value = "")
    public String getSourceAmount() {
        return sourceAmount;
    }
    public void setSourceAmount(String sourceAmount) {
        this.sourceAmount = sourceAmount;
    }
    public FXInquirypostPayload sourceAmount(String sourceAmount) {
        this.sourceAmount = sourceAmount;
        return this;
    }

    /**
     * Get Source Currency Code
     * @return Source Currency Code
     *
     * Possible values : Alphanumeric length: 3
     * Reference url:
     * https://developer.visa.com/request_response_codes#iso_country_and_currency_codes
     **/
    @ApiModelProperty(required = true, value = "")
    public String getSourceCurrencyCode() {
        return sourceCurrencyCode;
    }
    public void setSourceCurrencyCode(String sourceCurrencyCode) {
        this.sourceCurrencyCode = sourceCurrencyCode;
    }
    public FXInquirypostPayload sourceCurrencyCode(String sourceCurrencyCode) {
        this.sourceCurrencyCode = sourceCurrencyCode;
        return this;
    }

    /**
     * Get Systems Trace Audit Number
     * @return Systems Trace Audit Number
     *
     * Possible values : integer positive, length: 6
     * It is recommended that the clients of Funds Transfer APIs provide systemsTraceAuditNumber
     * to tie the calls with a single funds transfer transaction.
     **/
    @ApiModelProperty(value = "Systems Trace Audit Number")
    public String getSystemsTraceAuditNumber() {
        return systemsTraceAuditNumber;
    }
    public void setSystemsTraceAuditNumber(String systemsTraceAuditNumber) {
        this.systemsTraceAuditNumber = systemsTraceAuditNumber;
    }
    public FXInquirypostPayload systemsTraceAuditNumber(String systemsTraceAuditNumber) {
        this.systemsTraceAuditNumber = systemsTraceAuditNumber;
        return this;
    }

    @Override
    public String toString() {
        return new String("class FXInquirypostPayload {\n\tcardAcceptor: " + cardAcceptor
                + "\n\tdestinationCurrencyCode: " + destinationCurrencyCode + "\n\tmarkUpRate: "
                + markUpRate + "\n\tretrievalReferenceNumber: " + retrievalReferenceNumber
                + "\n\tsourceAmount: " + sourceAmount + "\n\tsourceCurrencyCode: "
                + sourceCurrencyCode + "\n\tsystemsTraceAuditNumber: " + systemsTraceAuditNumber
                + "\n}");
    }

}